/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.learn;

import com.liferay.petra.string.StringBundler;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.json.JSONObject;

/**
 * @author Brian Wing Shun Chan
 */
public class LearnMessage {

	public LearnMessage(JSONObject jsonObject, String key, String languageId) {
		if (jsonObject.length() == 0) {
			return;
		}

		JSONObject keyJSONObject = jsonObject.getJSONObject(key);

		if (keyJSONObject == null) {
			return;
		}

		JSONObject languageIdJSONObject = keyJSONObject.getJSONObject(
			languageId);

		if (languageIdJSONObject == null) {
			if (languageId.equals("en_US")) {
				return;
			}

			languageIdJSONObject = keyJSONObject.getJSONObject("en_US");

			if (languageIdJSONObject == null) {
				return;
			}
		}

		_message = languageIdJSONObject.getString("message");
		_url = languageIdJSONObject.getString("url");

		_html = StringBundler.concat(
			"<a href=\"", _url, "\" target=\"_blank\">", _message, "</a>");
	}

	public String getHTML() {
		return _html;
	}

	public String getMessage() {
		return _message;
	}

	public String getURL() {
		return _url;
	}

	private String _html = StringPool.BLANK;
	private String _message = StringPool.BLANK;
	private String _url = StringPool.BLANK;

}